@@ -18,3 +18,9 @@ class ClothingType(AvatarPart):
     SHIRT_CREW_NECK = 'shirt_crew_neck'
     SHIRT_SCOOP_NECK = 'shirt_scoop_neck'
     SHIRT_V_NECK = 'shirt_v_neck'
+    ASTRONAUT_SUIT = 'astronaut_suit'
+    BOND_SUIT = 'bond_suit'
+    CHEF = 'chef'
+    GLADIATOR = 'gladiator'
+    JEDI_ROBE = 'jedi_robe'
+    SHIRT_WICK = 'shirt_wick'
